@@ -1,5 +1,5 @@
 /*
-	htpdate v1.2.0
+	htpdate v1.2.1
 
 	Eddy Vervest <eddy@vervest.org>
 	http://www.vervest.org/htp
@@ -52,7 +52,7 @@
 #include <pwd.h>
 #include <grp.h>
 
-#define VERSION 				"1.2.0"
+#define VERSION 				"1.2.1"
 #define	MAX_HTTP_HOSTS			15				/* 16 web servers */
 #define	DEFAULT_HTTP_PORT		"80"
 #define	DEFAULT_PROXY_PORT		"8080"
@@ -307,6 +307,7 @@ static long getHTTPdate( char *host, char *port, char *proxy, char *proxyport, c
 		if ( (pdate = strstr(buffer, "Date: ")) != NULL && strlen( pdate ) >= 35 ) {
 			strncpy(remote_time, pdate + 11, 24);
 
+			memset(&tm, 0, sizeof(struct tm));
 			if ( strptime( remote_time, "%d %b %Y %T", &tm) != NULL) {
 				timevalue.tv_sec = gmtmktime(&tm);
 			} else {
@@ -829,7 +830,7 @@ int main( int argc, char *argv[] ) {
 			if ( sleeptime < maxsleep )
 				sleeptime <<= 1;
 		}
-		if ( debug )
+		if ( debug && daemonize )
 			printlog( 0, "poll %ld s", sleeptime ); 
 
 	} else {
